==> cms-db_v0.6.tar.gz: admin/urlindex.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

function _urlindex_get_pages($folder = '') {
	if (!isset($pages)) {
		static $pages = array();
	}
	$dir = '../data/pages/'.$folder;
	$handle = opendir($dir);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($dir.'/'.$file)) {
				_urlindex_get_pages($folder.'/'.$file);
			} else {
				$pages[] = $folder.'/'.$file;
			}
		}
	}
	closedir($handle);
	return $pages;
}

function _urlindex_get_url($page, $urls) {
	$split = explode('/', $page);
	$count = count($split);
	if ($split[$count-1] == '01,Home') {
		$url = $split[$count-2];
	} else {
		$url = $split[$count-1];
	}
	$url = substr($url, 3);
	$url = str_replace(array('.DEL', 'SLASH'), array('', '-'), $url);
	$url = strtolower($url);
	$url = str_replace(array('(', ')'), '', $url);
	$replace_pairs = array(	'_'	=>	'-',
							'ä'	=>	'ae',
							'Ä' =>	'ae',
							'ö'	=>	'oe',
							'Ö' =>	'oe',
							'ü'	=>	'ue',
							'Ü' =>	'ue',
							'ß'	=>	'ss' );
	$url = strtr($url, $replace_pairs);
	$url = preg_replace('/W/', '', $url);
	if (in_array($url, $urls)) {
		$i = 2;
		while (in_array($url.'-'.$i, $urls)) {
			$i++;
		}
		$url = $url.'-'.$i;
	}
	return $url;
}

function generate_urlindex() {
	$pages = _urlindex_get_pages();
	natcasesort($pages);
	$urls = array();
	$urlindex = '';
	foreach($pages as $page) {
		$url = _urlindex_get_url($page, $urls);
		$urls[] = $url;
		$urlindex .= $url."\t".$page."\n";
	}
	$handle = fopen('../data/urlindex.txt', 'w+');
	fwrite($handle, $urlindex."\n");
	fclose($handle);
}
?>

==> cms-db_v0.6.1.tar.gz: admin/urlindex.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

function _urlindex_get_pages($folder = '') {
	if (!isset($pages)) {
		static $pages = array();
	}
	$dir = '../data/pages/'.$folder;
	$handle = opendir($dir);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($dir.'/'.$file)) {
				_urlindex_get_pages($folder.'/'.$file);
			} else {
				$pages[] = $folder.'/'.$file;
			}
		}
	}
	closedir($handle);
	return $pages;
}

function _urlindex_get_url($page, $urls) {
	$split = explode('/', $page);
	$count = count($split);
	if ($split[$count-1] == '01,Home') {
		$url = $split[$count-2];
	} else {
		$url = $split[$count-1];
	}
	$url = substr($url, 3);
	$url = str_replace(array('.DEL', 'SLASH', 'AND'), array('', '-', '-'), $url);
	$url = strtolower($url);
	$replace_pairs = array(	'_'	=>	'-',
							'ä'	=>	'ae',
							'Ä' =>	'ae',
							'ö'	=>	'oe',
							'Ö' =>	'oe',
							'ü'	=>	'ue',
							'Ü' =>	'ue',
							'ß'	=>	'ss' );
	$url = strtr($url, $replace_pairs);
	$url = preg_replace('/[^\w-]/', '', $url);
	$url = preg_replace('/-+/', '-', $url);
	if (in_array($url, $urls)) {
		$i = 2;
		while (in_array($url.'-'.$i, $urls)) {
			$i++;
		}
		$url = $url.'-'.$i;
	}
	return $url;
}

function generate_urlindex() {
	$pages = _urlindex_get_pages();
	natcasesort($pages);
	$urls = array();
	$urlindex = '';
	foreach($pages as $page) {
		$url = _urlindex_get_url($page, $urls);
		$urls[] = $url;
		$urlindex .= $url."\t".$page."\n";
	}
	$handle = fopen('../data/urlindex.txt', 'w+');
	fwrite($handle, $urlindex."\n");
	fclose($handle);
}
?>
